@@ -30,5 +30,8 @@ def get_sentence_embedding(model, sentence, add_pos_weight=['n','nr','ng','ns','
 
 # 获取句子相似度
 def get_vector_similarity(query_vec,vec_list,metric_type='cos'):
-    vector_similarity = textembedding.get_embedding.get_similarity(query_vec,vec_list,metric_type)
-    return vector_similarity
\ No newline at end of file
+    if isinstance(query_vec,str) and isinstance(vec_list, str):
+        vector_similarity = textembedding.get_embedding.get_tfidf_similarity(query_vec,vec_list)
+    else:
+        vector_similarity = textembedding.get_embedding.get_similarity(query_vec,vec_list,metric_type)
+    return vector_similarity
