@@ -22,3 +22,7 @@ def get_sentence_embedding(model,sentence, add_pos_weight=['n','nr','ng','ns','n
 def get_similarity(query_vec, vec_list, metric_type='cos'):
     vector_similarity = textembedding.get_embedding.similarity.get_similarity(query_vec,vec_list,metric_type)
     return vector_similarity
+
+def get_tfidf_similarity(sentence1, sentence2):
+    vector_similarity = textembedding.get_embedding.similarity.tfidf_similarity(sentence1, sentence2)
+    return vector_similarity
